@@ -5,6 +5,7 @@ from typing import Union
 import jaaql.utilities.crypt_utils as crypt_utils
 from jaaql.db.db_pg_interface import DBPGInterface
 from jaaql.db.db_interface import DBInterface
+from jaaql.utilities.utils_no_project_imports import objectify
 
 ERR__encryption_key_required = "Encryption key required. Check internal function calls"
 ERR__duplicated_encrypt_parameter = "Duplicated value in encrypt_parameters list"
@@ -55,7 +56,7 @@ def execute_supplied_statement(db_interface, query: str, parameters: dict = None
                                as_objects: bool = False, encrypt_parameters: list = None,
                                decrypt_columns: list = None, encryption_key: bytes = None,
                                encryption_salts: dict = None, skip_commit: bool = False,
-                               autocommit: bool = False):
+                               autocommit: bool = False, do_prepare_only: bool = False):
     if parameters is None:
         parameters = {}
 
@@ -101,10 +102,11 @@ def execute_supplied_statement(db_interface, query: str, parameters: dict = None
         "decrypt": decrypt_columns
     }
 
-    data = InterpretJAAQL(db_interface).transform(statement, skip_commit=skip_commit, encryption_key=encryption_key, autocommit=autocommit)
+    data = InterpretJAAQL(db_interface).transform(statement, skip_commit=skip_commit, encryption_key=encryption_key, autocommit=autocommit,
+                                                  do_prepare_only=do_prepare_only)
 
     if as_objects:
-        data = db_interface.objectify(data)
+        data = objectify(data)
 
     return data
 
@@ -133,9 +135,11 @@ def execute_supplied_statement_singleton(db_interface, query, parameters: dict =
                                          as_objects: bool = False, encrypt_parameters: list = None,
                                          decrypt_columns: list = None, encryption_key: bytes = None,
                                          encryption_salts: dict = None, singleton_code: int = None,
-                                         singleton_message: str = None, skip_commit: bool = False):
+                                         singleton_message: str = None, skip_commit: bool = False,
+                                         do_prepare_only: bool = False):
     data = execute_supplied_statement(db_interface, query, parameters, as_objects, encrypt_parameters,
-                                      decrypt_columns, encryption_key, encryption_salts, skip_commit=skip_commit)
+                                      decrypt_columns, encryption_key, encryption_salts, skip_commit=skip_commit,
+                                      do_prepare_only=do_prepare_only)
 
     return force_singleton(data, as_objects, singleton_code, singleton_message)
 
@@ -161,7 +165,7 @@ def execute_supplied_statements(db_interface, queries: Union[str, list],
     data = InterpretJAAQL(db_interface).transform(statement)
 
     if as_objects:
-        data = [db_interface.objectify(obj) for obj in data]
+        data = [objectify(obj) for obj in data]
 
     return data
 
